util

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 2, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterFS

func RegisterFS(ctx context.Context, p gas.TemplateProvider, fsys fs.FS, ext string) error

RegisterFS recursively registers template files from the provided file system with the specified extension to the TemplateProvider. It reads file contents and registers them using their slash-separated paths. Returns an error if reading or traversal fails.

Types

This section is empty.

Jump to