Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterFS ¶
RegisterFS recursively registers template files from the provided file system with the specified extension to the TemplateProvider. It reads file contents and registers them using their slash-separated paths. Returns an error if reading or traversal fails.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.